@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: statistics
 version: 0.13.2.3
-id: statistics-0.13.2.3-ea8e7d1808ba456bb62cfdee2801b88f
-key: stati_5khFPeaIX18DCiNCJf63RD
+id: statistics-0.13.2.3-9cfca80e6aade4eaf97a03a2085a3b43
+key: stati_63G6Zey3UJB0HQiuuAibsd
 license: BSD3
 copyright: 2009-2014 Bryan O'\''Sullivan
 maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
@@ -63,20 +63,20 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/statistics-0.13.2.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/statistics-0.13.2.3
-hs-libraries: HSstatistics-0.13.2.3-5khFPeaIX18DCiNCJf63RD
+hs-libraries: HSstatistics-0.13.2.3-63G6Zey3UJB0HQiuuAibsd
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     erf-2.0.0.0-aab48415b057e47fae23d9f8b194cc70
-    math-functions-0.1.5.2-7a985a285f902888d75b2085436cd768
+    math-functions-0.1.6.0-ea20ce369bb9f305d4ce2d1a9db5e80e
     monad-par-0.3.4.7-71f3c038a9542ac299ca5b790fa5b12a
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
-    vector-binary-instances-0.2.3.1-2255e15260ecf66ec12e6381e175b94d
+    vector-binary-instances-0.2.3.2-10501af4370a6bd9af714ba6aadb9040
 haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
 haddock-html: /usr/share/doc/haskell-statistics/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
